@@ -44,6 +44,7 @@ class SymbolIni:
         """ """
         # remove later
         # config path is linked as PYAMI
+
         self.pyami_home = os.getenv(self.PYAMI_HOME)  # "/Users/pm286/pyami/"
         if not self.pyami_home:
             self.logger.fatal(f" environment variable $PYAMI_HOME must be set")
@@ -57,16 +58,16 @@ class SymbolIni:
             sys.exit(1)
 
         self.pyami.args[self.CONFIG] = config_ini  # "/Users/pm286/pyami/config.ini.master"
-        self.logger.warning(f"config path in args: {config_ini}")
+        self.logger.debug(f"config path in args: {config_ini}")
         config_files_str = self.pyami.args.get(self.CONFIG)
         config_files = [] if config_files_str is None else config_files_str.split(",")
         self.symbols = {}
         self.fileset = set()
-        self.logger.warning(f"config files {config_files_str}")
+        self.logger.debug(f"config files {config_files_str}")
         for config_file in config_files:
             self.logger.info(f"****processing config: {config_file}")
             self.process_config_file(config_file)
-        self.logger.warning(f"symbols after config {self.symbols}")
+        self.logger.debug(f"symbols after config {self.symbols}")
 
     def process_config_file(self, config_file):
         """
@@ -75,8 +76,8 @@ class SymbolIni:
 
         """
         # this is the config path pointed to by PYAMI
-        self.logger.warning(f"config path {config_file}")
-        self.logger.warning(f"package {__package__}, path {__file__}, parent.parent {Path(__file__).parent.parent}", )
+        self.logger.info(f"config path {config_file}")
+        self.logger.info(f"package {__package__}, path {__file__}, parent.parent {Path(__file__).parent.parent}", )
         if config_file.startswith("${") and config_file.endswith("}"):  # python config path
             file = os.environ[config_file[2:-1]]
         elif "/" not in config_file:
@@ -131,7 +132,7 @@ class SymbolIni:
         files_read = self.config.read(file)
         sections = self.config.sections()
         for section in sections:
-            self.logger.warning(f"SECTION [{section}] in config path: {file}")
+            self.logger.debug(f"SECTION [{section}] in config path: {file}")
             self.convert_section_into_symbols_dict(file, section)
 
         # self.print_symbols()
@@ -253,6 +254,7 @@ assumes value
         result = ""
         start = 0
         self.logger.info(f"expanding symbols in {arg}")
+        arg = str(arg)
         while SymbolIni.SYM_START in arg[start:]:
             idx0 = arg.index(SymbolIni.SYM_START, start)
             result += arg[start:idx0]
