@@ -1,3 +1,4 @@
+import json
 import logging
 import os
 
@@ -196,6 +197,24 @@ class WikidataBrowser:
         for subelem in element.xpath(xpath):
             subelem.getparent().remove(subelem)
 
+class WikidataFilter:
+
+    @classmethod
+    def create_filter(cls, file):
+        if not file:
+            return None
+        if not file.exists():
+            print(f"no file {file}")
+            return None
+        filter = WikidataFilter()
+        print(f"file.. {file}")
+        with open(file, "r") as f:
+            text = f.read()
+        filter.json = json.loads(text)
+        print(f"dict {type(filter.json)} {filter.json}")
+        return filter
+
+
 
 class WikidataProperty:
 
@@ -498,9 +517,7 @@ class WikidataPage:
         desc_list = self.get_elements_for_normalized_attrib_val("class", "wikibase-entitytermsview-heading-description")
         # desc_list = self.root.xpath(
         #     f"/html//*[normalize-space(@class)='wikibase-entitytermsview-heading-description']")
-        assert desc_list is not None
-        assert len(desc_list) == 1
-        desc = desc_list[0].text
+        desc = "" if not desc_list else desc_list[0].text
         return desc
 
     def get_elements_for_normalized_attrib_val(self, attname, attval, lead="//*", trail=""):
